@@ -6,18 +6,18 @@ use Mojo::Util 'monkey_patch';
 use JSON::MaybeXS 'JSON';
 use Mojo::JSON ();
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
-my $BINARY = JSON::MaybeXS->new(utf8 => 1, allow_nonref => 1,
+my $BINARY = JSON::MaybeXS->new(utf8 => 1, canonical => 1, allow_nonref => 1,
 	allow_unknown => 1, allow_blessed => 1, convert_blessed => 1);
-my $TEXT = JSON::MaybeXS->new(utf8 => 0, allow_nonref => 1,
+my $TEXT = JSON::MaybeXS->new(utf8 => 0, canonical => 1, allow_nonref => 1,
 	allow_unknown => 1, allow_blessed => 1, convert_blessed => 1);
 my $TRUE = JSON->true;
 my $FALSE = JSON->false;
 
 if (JSON eq 'Cpanel::JSON::XS') {
 	local $@;
-    if (eval { Cpanel::JSON::XS->VERSION('3.0112'); 1 }) {
+	if (eval { Cpanel::JSON::XS->VERSION('3.0112'); 1 }) {
 		$BINARY->stringify_infnan;
 		$TEXT->stringify_infnan;
 	}
@@ -30,11 +30,11 @@ if (JSON eq 'Cpanel::JSON::XS') {
 	$TEXT->escape_slash;
 }
 
-monkey_patch 'Mojo::JSON', 'encode_json', sub { $BINARY->encode(shift) };
-monkey_patch 'Mojo::JSON', 'decode_json', sub { $BINARY->decode(shift) };
+monkey_patch 'Mojo::JSON', 'encode_json', sub { $BINARY->encode($_[0]) };
+monkey_patch 'Mojo::JSON', 'decode_json', sub { $BINARY->decode($_[0]) };
 
-monkey_patch 'Mojo::JSON', 'to_json',   sub { $TEXT->encode(shift) };
-monkey_patch 'Mojo::JSON', 'from_json', sub { $TEXT->decode(shift) };
+monkey_patch 'Mojo::JSON', 'to_json',   sub { $TEXT->encode($_[0]) };
+monkey_patch 'Mojo::JSON', 'from_json', sub { $TEXT->decode($_[0]) };
 
 monkey_patch 'Mojo::JSON', 'true',  sub () { $TRUE };
 monkey_patch 'Mojo::JSON', 'false', sub () { $FALSE };
@@ -51,7 +51,7 @@ Mojo::JSON::MaybeXS - use JSON::MaybeXS as the JSON encoder for Mojolicious
  use Mojo::JSON qw/encode_json decode_json true false/;
  
  # Preload for scripts using Mojo::JSON
- $ perl -MMojo::JSON::MaybeXS $(which morbo) myapp.pl
+ $ perl -MMojo::JSON::MaybeXS -S morbo myapp.pl
  
  # Must be set in environment for hypnotoad
  $ PERL5OPT=-MMojo::JSON::MaybeXS hypnotoad myapp.pl
@@ -71,13 +71,14 @@ L<Mojo::JSON> and occasionally from each other. References to the behavior of
 L<JSON::MaybeXS> below are actually describing the behavior shared among the
 modules it loads.
 
-L<JSON::MaybeXS> is used with the options C<allow_nonref>, C<allow_unknown>,
-C<allow_blessed>, and C<convert_blessed>. C<allow_nonref> allows encoding and
-decoding of bare values outside of hash/array references, since L<Mojo::JSON>
-does not prevent this, in accordance with
-L<RFC 7159|http://tools.ietf.org/html/rfc7159>. The other options prevent the
-encoder from blowing up when encountering values that cannot be represented in
-JSON to better match the behavior of L<Mojo::JSON>; in most cases, where
+L<JSON::MaybeXS> is used with the options C<canonical>, C<allow_nonref>,
+C<allow_unknown>, C<allow_blessed>, and C<convert_blessed>. C<canonical>
+enables sorting of hash keys when encoding to JSON objects as L<Mojo::JSON>
+does. C<allow_nonref> allows encoding and decoding of bare values outside of
+hash/array references, since L<Mojo::JSON> does not prevent this, in accordance
+with L<RFC 7159|http://tools.ietf.org/html/rfc7159>. The other options prevent
+the encoder from blowing up when encountering values that cannot be represented
+in JSON to better match the behavior of L<Mojo::JSON>; in most cases, where
 L<Mojo::JSON> would stringify a reference, L<JSON::MaybeXS> with these settings
 will encode it to C<null>. See below for more specifics.
 
